function [Haared]=Haar(field,calibcoord,lowpts,highpts)
%field is a two dimensional array
%lowpts and highpts are the number of points at low and high lags that
%should be dropped before estimating exponents
%calibcoord is for the calibration of the time/space axis. It is the resolution in some basic units. 
%For example calibcoord=1/12 gives result in units of years. 
%Use convention that largest lag = length of data series
%Range of scales over which fluctuations are calculated is dim/2 
[num,dim]=size(field);
calib=2;
%calib is overall multiplier used only for grRMS and grq1 that takes into account the calibration with respect to difference and tendency fluctuations
qmax=21;
delq=0.1;
qeps=0.0001;
%With these parameters moments are caluculated every 0.1 from 0 to q=2
%qeps added to avoid exponenting to zero power(if data contains zero values)
qtab=qeps:delq:delq*qmax+qeps-delq;
fac=2;%fac=2 for orbital data, then largest lag is half length of data series
pt=10^6;
points0=floor(20*log10((pt-0.001)/fac));
ddelt0=2:2:22;
maxpt=2*floor(dim./(2*fac));
i=28:points0;
ddelt=2*floor(10.^(i./20)/2);
ddelt=[ddelt0,ddelt];
ddelt=ddelt(ddelt<(maxpt+0.001));
points=length(ddelt);
if ddelt(points)==dim
    ddelt(points)=ddelt(points)-2;
end
coord=log10(ddelt);
premoms=zeros(points,qmax);
moms=zeros(points,qmax);
for j=1:num
    for y=1:points
        R=cumsum(field(j,:)-mean(field(j,:)));
        RR=wrev(R);
        delt=ddelt(y);
        Rdelt=circshift(R,[0,delt]);
        Rdelt2=circshift(R,[0,delt/2]);
        delR=(2*abs(R+Rdelt-2*Rdelt2))./delt;
        RRdelt=circshift(RR,[0,delt]);
        RRdelt2=circshift(RR,[0,delt/2]);
        delRR=(2*abs(RR+RRdelt-2*RRdelt2))./delt;
        take1=delR(delt+1:delt:dim);
        take2=delRR(delt+1:delt:dim);
        tt=[take1,take2];
        mat=zeros(length(tt),qmax);
        for i=1:length(tt)
            mat(i,:)=tt(i).^qtab;
        end
            M=mean(mat);
            premoms(y,:)=M;
    end
    moms=moms+premoms;
end
moms=moms';
moms=log10(moms./num);
low=max(1,1+lowpts);
high=max(low+2,points-highpts);
coordcalib=coord+log10(calibcoord);
%Fits are over the range 10.^(coordcalib(low,:)) to 10.^(coordcalib(high,:))
p=zeros(2,qmax);
for q=1:qmax
T=cat(1,coordcalib,moms(q,:))';
take=T(low:high,1:2);
x=take(:,1);
y=take(:,2);
f=polyfit(x,y,1);
p(1,q)=f(1);
p(2,q)=f(2);
end
inter=p(2,:);
hqneg=p(1,:);
x=coordcalib(low):0.01:coordcalib(high);
figure
hold on
for j=1:qmax,
    y=log10(calib)+inter(j)+hqneg(j)*x;
    grref(j)=plot(x,y);
end
set(gca,'FontSize',18);

hold off

ColOrd=get(gca,'ColorOrder');
[m,n]=size(ColOrd);
hold on
for k=1:qmax,
    ColRow=rem(k,m);
    if ColRow==0
        ColRow=m;
    end
    Col=ColOrd(ColRow,:);
    T=cat(1,coordcalib,moms(k,:)+log10(calib))';
    gr(k)=plot(T(:,1),T(:,2),'Color',Col);
    xlabel('Log_{10} \Delta t')
    ylabel('Log_{10} S(\Delta t)')
    set(gca,'FontSize',18);
end
hold off
axis normal
%Colors each line on the plot uniquely

figure
Q=1:qmax;
psi=[qtab(Q);hqneg(Q)];
plot(psi(1,:),psi(2,:));
xlabel('q');
ylabel('\xi (q)');
title('grpsi','FontSize',18);
set(gca,'FontSize',18);

tK=psi';
ttK=tK(9:13,1:2);
ft=polyfit(ttK(:,1),ttK(:,2),2);
%The RMS exponent=K(2)/2=psi(11,2)
H=ft(1)+ft(2)+ft(3);
derivativeC1=H-2*ft(1)-ft(2);
alpha=-2*ft(1)/derivativeC1;
Haared={'H',H;'Derivative C1',derivativeC1;'alpha',alpha};

C1data=cat(1,coordcalib,log10(Smooth1D(10.^moms(11,:)))-5*log10(Smooth1D(10.^(moms(12,:)-moms(10,:)))));

%You can see the graphs of
%grC1,grC1theory,grRMS,grRMSsmooth,grtheoryRMS,grtheorydataRMS,grq1smooth,grtheorydataq1,grq1,grall,grallsmooth,grKppsmoooth,
%and grKpptheory by simply removing the % signs.

%figure
%grC1
xx=C1data(1,:);
yy=C1data(2,:);
%plot(xx,yy);
%xlabel('Log_{10} \Delta t');
%ylabel('Log_{10} \Delta t^{C_{1}}');
%title('grC1');

fitdat=C1data(:,low:high);
aa=polyfit(fitdat(1,:),fitdat(2,:),1);
interC1=aa(2);
hqnegC1=aa(1);

%figure
%grC1theory
YY=interC1+hqnegC1*x;
%plot(x,YY);
%C1 graph slope method=hqnegC1

figure
plot(x,YY);%grC1theory
hold on
plot(xx,yy);%grC1
title('grC1theorydata','FontSize',18)
xlabel('Log_{10} \Delta t')
ylabel('Log_{10} \Delta t^{C_{1}}')
set(gca,'FontSize',18);
hold off

%figure
%grRMs
xx1=coordcalib;
yy1=log10(calib)+(moms(21,:)./2);
%plot(xx1,yy1);
%xlabel('Log_{10} \Delta t')
%ylabel('Log_{10} S_{2}(\Delta t)^{1/2}')
%title('grRMS')

%figure
%grRMSsmooth
yy2=log10(calib)+(log10(Smooth1D(10.^moms(21,:))))/2;
%plot(xx1,yy2);
%xlabel('Log_{10} \Delta t')
%ylabel('Log_{10} S_{2}(\Delta t)^{1/2}')
%title('grRMSsmooth')

%figure
%grtheoryRMS
yy3=log10(calib)+inter(:,21)./2+(hqneg(:,21)./2)*x;
%plot(x,yy3);

%figure
%plot(x,yy3);%grtheoryRMS
%hold on
%plot(xx1,yy2);%grRMSsmooth
%xlabel('Log_{10} \Delta t')
%ylabel('Log_{10} S_{2}(\Delta t)^{1/2}')
%title('grtheorydataRMS');
%hold off

%figure
%grq1smooth
yy4=log10(calib)+log10(Smooth1D(10.^moms(11,:)));
%plot(xx1,yy4);
%xlabel('Log_{10} \Delta t')
%ylabel('Log_{10} S_{1}(\Delta t)')
%title('grq1smooth')

%figure
%plot(xx1,yy4);%grq1smooth
%hold on
yy5=log10(calib)+inter(:,11)+hqneg(:,11)*x;
%plot(x,yy5);%grtheoryq1
%title('grtheorydataq1')
%hold off

%figure
%grq1
yy6=log10(calib)+moms(11,:);
%plot(xx1,yy6);
%xlabel('Log_{10} \Delta t')
%ylabel('Log_{10} S_{1}(\Delta t)')
%title('grq1')

%figure
%plot(xx1,yy6);%grq1
%hold on
%plot(xx1,yy1);%grRMS
%title('grall')
%hold off

%figure
%plot(xx1,yy4);%grq1smooth
%hold on
%plot(xx1,yy2);%grRMSsmooth
%title('grallsmooth')
%hold off

figure
plot(xx1,yy4);%grq1smooth
hold on
plot(x,yy5);%grtheoryq1
hold off
hold on
plot(xx1,yy2);%grRMSsmooth
hold off
hold on
plot(x,yy3);%grtheoryRMS
title('gralldatatheory','FontSize',18);
xlabel('Log_{10} \Delta t')
ylabel('Log_{10} S(\Delta t)')
set(gca,'FontSize',18);
hold off

Kppdata=cat(1,coordcalib,-25*log10(Smooth1D(10.^(moms(13,:)+moms(9,:)-2*moms(11,:)))));

px=Kppdata(1,low:high);
py=Kppdata(2,low:high);
aaKpp=polyfit(px,py,1);
hqnegKpp=aaKpp(1);
interKpp=aaKpp(2);

%figure
%grKppsmooth
yy7=-25*log10(Smooth1D(10.^(moms(13,:)+moms(9,:)-2*moms(11,:))));
%plot(xx1,yy7);
%xlabel('Log_{10} \Delta t')
%ylabel('Log_{10} \Delta t^{K''(1)}')
%title('grKppsmooth')

%figure
%grKpptheory
yy8=interKpp+hqnegKpp*x;
%plot(x,yy8);

%figure
%plot(x,yy8);%grKpptheory
%hold on
%plot(xx1,yy7)%grKppsmooth
%title('grKpptheorydata')
%hold off

figure
plot(x,yy8)%grKpptheory
hold on
plot(xx1,yy7)%grKppsmooth
hold off
hold on
plot(xx,yy)%grC1
hold off
hold on
plot(x,YY)%grC1theory
title('grallC1Kpp','FontSize',18)
xlabel('Log_{10} \Delta t')
ylabel('Log_{10} \Delta t^{C_{1}}')
set(gca,'FontSize',18);
hold off

end
